pub struct FqCodelQdStats {
pub maxpacket: u32,
pub drop_overlimit: u32,
pub ecn_mark: u32,
pub new_flow_count: u32,
pub new_flows_len: u32,
pub old_flows_len: u32,
pub ce_mark: u32,
pub memory_usage: u32,
pub drop_overmemory: u32,
}Fields
maxpacket: u32Largest packet we’ve seen so far
drop_overlimit: u32Number of time max qdisc packet limit was hit.
ecn_mark: u32Number of packets ECN marked instead of being dropped.
new_flow_count: u32Number of time packets created a ‘new flow’.
new_flows_len: u32Count of flows in new list.
old_flows_len: u32Count of flows in old list.
ce_mark: u32Packets above ce_threshold.
memory_usage: u32Memory usage (bytes).
drop_overmemory: u32Number of time packets were dropped due to memory limit.